#include "lcd.h"
#include "font_5x7.h"

void LCD_Init(void)
{
	LCD_CSA = 1;						//slectionner contrleur A
	LCD_CSB = 1;						//slectionner contrleur B

	LCD_Enable = 0;						//dsactiver broche enable

	LCD_Reset = 0;						//reset  0
	Delay100TCYx(1);					//attendre 100 cycles
	LCD_Reset = 1;						//reset  1
	
	LCD_Write_Command(0b00111111);		//display ON
	
}

void LCD_Write_Command(unsigned char Data)
{
	LCD_RS = 0;					//mode instruction
	LCD_RW = 0;					//sous-mode criture

	LCD_DATA = Data;			//placer donne sur le port

	Delay100TCYx(1);			//attendre 100 cycles
	Delay100TCYx(1);			//attendre 100 cycles

	LCD_Enable = 1;				//dsactiver broche enable
	Delay100TCYx(1);			//attendre 100 cycles
	Delay100TCYx(1);			//attendre 100 cycles
	LCD_Enable = 0;				//activer broche enable

}


void LCD_Send_Data(unsigned char Data)
{
	LCD_RS = 1;					//mode donne
	LCD_RW = 0;					//sous-mode criture

	LCD_DATA = Data;			//placer donne sur le port

	Delay100TCYx(2);			//attendre 100 cycles

	LCD_Enable = 1;				//dsactiver broche enable
	Delay100TCYx(2);			//attendre 100 cycles
	LCD_Enable = 0;				//activer broche enable

}


unsigned char LCD_Read_Data(void)
{
	unsigned char port;	

	TRISD = 0b11111111;			//configuration du PORTD > data lcd en entre

	LCD_RS = 1;					//mode donne
	LCD_RW = 1;					//sous-mode lecture

	LCD_Enable = 1;				//dsactiver broche enable
	Delay100TCYx(1);			//attendre 100 cycles
	LCD_Enable = 0;				//activer broche enable

	port=PORTD;

	TRISD = 0b00000000;			//configuration du PORTD > data lcd en sortie

	return port;
}


void LCD_Clear(void)
{
	int i=0;
	int j=0;

	LCD_CSA=1;					//selectionner zone A
	LCD_CSB=1;					//selectionner zone B

	for(i=0; i<=7;i++)			//pour i allant de 0  7 (7 pages)
	{	
		LCD_Write_Command(0xB8+i);	//selectionner page

		for(j=0;j<64;j++)
			LCD_Send_Data(0);	//envoyer donne nulle
	
	}

	LCD_Write_Command(0xB8);	//retourner en page 1

	Delay10KTCYx(50);			//attendre 50000 cycles

}


void LCD_GotoXY(unsigned char X, unsigned char Y)
{
	if(X<64)
	{
		LCD_CSA=0;
		LCD_CSB=1;
		LCD_Write_Command(0xB8+Y);
		LCD_Write_Command(0x40+X);
	}

	else
	{
		LCD_CSA=1;
		LCD_CSB=0;
		LCD_Write_Command(0xB8+Y);
		LCD_Write_Command(0x40+(X-64));
	}
}


void LCD_PutChar(char ch)
{
	int k;
	for(k=0;k<5;k++)
		LCD_Send_Data(Font[(int)(ch-32)*5+k]);
	LCD_Send_Data(0);
	
}


void LCD_PutStringRom(const rom char *tab, unsigned char X, unsigned char Y)
{
	int c=0;
	int x=X;

	LCD_GotoXY(X*6,Y);

	for(c=0 ; tab[c]!=0 ; c++)
	{	
		if(((x%10)==0)&(x!=0))
		{	
			X=65;
			LCD_GotoXY(X,Y);
		}

		if(((x%20)==0)&(x!=0))
		{
			X=0;
			Y=Y+1;
			LCD_GotoXY(X,Y);
		}

		LCD_PutChar(tab[c]);

		x++;
	}
}


void LCD_PutString(const char *tab, unsigned char X, unsigned char Y)
{
	int c=0;
	int x=X;

	LCD_GotoXY(X*6,Y);

	for(c=0 ; tab[c]!=0 ; c++)
	{	
		if(((x%10)==0)&(x!=0))
		{	
			X=65;
			LCD_GotoXY(X,Y);
		}

		if(((x%20)==0)&(x!=0))
		{
			X=0;
			Y=Y+1;
			LCD_GotoXY(X,Y);
		}

		LCD_PutChar(tab[c]);

		x++;
	}
}

void LCD_PutPixel(unsigned char X, unsigned char Y)
{
	unsigned char Val, page=Y>>3;		//calcule la page courante
	
	LCD_GotoXY(X,page);					//place curseur

	Val=LCD_Read_Data();
	Val=LCD_Read_Data();

	Val=Val|(1<<(Y%8));

	LCD_GotoXY(X,page);					//replace curseur

	LCD_Send_Data(Val);					//envoie donne

}